==> kube-integration-1.15.8.tgz: package/lib/helm/release/helm3/revision.js <==
'use strict';

const _ = require('lodash');
const Promise = require('bluebird');
const {gunzip} = require('zlib');
const YAML = require('js-yaml');
const flatten = require('flat');



class ReleaseRevision {

    constructor(data){
        this._name = data[ReleaseRevision.commonProps.name];
        this._version = data[ReleaseRevision.commonProps.version];
        this._status = _.toUpper(data[ReleaseRevision.commonProps.status]);
        this._modifiedAt = data[ReleaseRevision.commonProps.modifiedAt];
        this._createdAt = data[ReleaseRevision.commonProps.createdAt];
        this._rawData = data.dataAsBase64;
    }

    get name(){
        return this._name;
    }

    get status(){
        return this._status;
    }

    get decodedObject(){
        return this._decodedObject;
    }

    get createdAt(){
        return this._createdAt;
    }

    get modifiedAt(){
        return this._modifiedAt;
    }

    get version(){
        return this._version;
    }

    get info(){
        return this._info;
    }

    _getUTCTime(date) {
        return Math.floor(new Date(date).getTime() / 1000)
    }

    _fromBaseNameToFullName(baseName, currentName){
        if(!baseName){
            return currentName
        }
        return `${baseName}/${currentName}`;
    }

    _setDecodedObject(obj){
        this._decodedObject = obj;
    }

    _getRevisionDecodedData(){
        const data = Buffer.from(this._rawData, 'base64');
        return Promise.fromCallback((cb) => gunzip(Buffer.from(data.toString(), 'base64'), cb))
            .then((releasePayload => {
                return this._normalizeSecretKeys(JSON.parse(releasePayload));
            }))
            .catch((err) => {
                return data;
            });
    }

    _getNormalizedMetadata(rootDirName){
        const metadata = _.get(this._decodedObject, 'chart.metadata', {});
        return Promise.resolve({
            name: this._fromBaseNameToFullName(rootDirName, 'Chart.yaml'),
            data: YAML.dump(metadata)
        });
    }

    _getNormalizedTemplates(rootDirName){
        const templatesList = _.get(this._decodedObject, 'chart.templates', []) || [];
        return Promise.map(templatesList, (template) => {
            return {
                name: this._fromBaseNameToFullName(rootDirName, template.name),
                data: Buffer.from(template.data, 'base64').toString(),
            };
        });
    }

    _getNormalizedDependencies(rootDirName){
        const dependenciesList = _.get(this._decodedObject, 'chart.dependenciesList', []) || [];
        return Promise.map(dependenciesList, (dependency) => {
            const version = 1;
            const name = _.get(dependency, 'metadata.name');
            const data = {
                NAME: name,
                VERSION: version,
                MODIFIED_AT: this.modifiedAt,
                CREATED_AT: this.createdAt,
                STATUS: this.status,
            }
            const revision = new ReleaseRevision(data);
            revision._setDecodedObject({
                chart: dependency,
            })
            return revision.getChart(`Charts/${name}`);
        });
    }

    _getNormalizedValues(rootDirName){
        const values = _.get(this._decodedObject, 'chart.values', {});
        return Promise.resolve({
            name: this._fromBaseNameToFullName(rootDirName, 'values'),
            data: YAML.dump(values),
        });
    }

    _normalizeSecretKeys(obj) {
        let flattenObj = flatten(obj, {
            transformKey: (key) => _.lowerFirst(key)
        });
        return flatten.unflatten(flattenObj)
    }

    _getNormalizedFiles(rootDirName){
        const filesList = _.get(this._decodedObject, 'chart.files', []) || [];
        return Promise.map(filesList, (file) => {
            return {
                name: this._fromBaseNameToFullName(rootDirName, file.name),
                data: Buffer.from(file.data, 'base64').toString(),
            };
        });
    }


    getBasicData(){
        return {
            version: this._version,
            createdAt: this._createdAt,
            modifiedAt: this._modifiedAt,
            status: this._status,
            info: this._info,
            name: this._name
        }
    }

    init() {
        return this._getRevisionDecodedData()
            .then((decodedObject) => {
                this._setDecodedObject(decodedObject);
                this._createdAt = this._getUTCTime(_.get(decodedObject, 'info.first_deployed', 0));
                this._modifiedAt = this._getUTCTime(_.get(decodedObject, 'info.last_deployed', 0));
                this._info = _.get(decodedObject, 'info.description');
            });
    }

    getChart(baseName){
        return Promise.all([
            this._getNormalizedMetadata(baseName),
            this._getNormalizedTemplates(baseName),
            this._getNormalizedDependencies(baseName),
            this._getNormalizedValues(baseName),
            this._getNormalizedFiles(baseName),
        ])
        .then(_.flattenDeep)
        .then(_.compact);
    }

    getManifest(){
        return YAML.safeLoadAll(_.get(this.decodedObject, 'manifest', ''))
            .map(obj => Object.assign({
                data: YAML.dump(obj)
            }));
    }
    getValues(){
        return Object.assign({
            data: YAML.dump(_.get(this.decodedObject, 'config', ''))
        });
    }
    getHooks(){
        return _.get(this.decodedObject, 'hooksList', []).map(hook => Object.assign({
            name: _.get(hook, 'path', ''),
            data: YAML.dump(_.get(hook, 'manifest', ''))
        }));
    }

}

ReleaseRevision.commonProps = {
    name: 'name',
    status: 'status',
    version: 'version',
    modifiedAt: 'modifiedAt',
    createdAt: 'createdAt',
    statusses: {
        deployed: 'deployed'
    }
};

module.exports = ReleaseRevision;

==> kube-integration-1.17.2.tgz: package/lib/helm/release/helm3/revision.js <==
'use strict';

const _ = require('lodash');
const Promise = require('bluebird');
const {gunzip} = require('zlib');
const YAML = require('js-yaml');
const BaseRevision = require('../base/revision');


class ReleaseRevision extends BaseRevision {

    constructor(data){
        super();
        this._name = data[ReleaseRevision.commonProps.name];
        this._version = data[ReleaseRevision.commonProps.version];
        this._status = _.toUpper(data[ReleaseRevision.commonProps.status]);
        this._modifiedAt = data[ReleaseRevision.commonProps.modifiedAt];
        this._createdAt = data[ReleaseRevision.commonProps.createdAt];
        this._rawData = data.dataAsBase64;
    }

    get name(){
        return this._name;
    }

    get status(){
        return this._status;
    }

    get decodedObject(){
        return this._decodedObject;
    }

    get createdAt(){
        return this._createdAt;
    }

    get modifiedAt(){
        return this._modifiedAt;
    }

    get version(){
        return this._version;
    }

    get info(){
        return this._info;
    }

    _getUTCTime(date) {
        return Math.floor(new Date(date).getTime() / 1000)
    }

    _fromBaseNameToFullName(baseName, currentName){
        if(!baseName){
            return currentName
        }
        return `${baseName}/${currentName}`;
    }

    _setDecodedObject(obj){
        this._decodedObject = obj;
    }

    _getRevisionDecodedData(){
        const data = Buffer.from(this._rawData, 'base64');
        return Promise.fromCallback((cb) => gunzip(Buffer.from(data.toString(), 'base64'), cb))
            .then((releasePayload => {
                return this._normalizeSecretKeys(JSON.parse(releasePayload));
            }))
            .catch((err) => {
                return data;
            });
    }

    _getNormalizedMetadata(rootDirName){
        const metadata = _.get(this._decodedObject, 'chart.metadata', {});
        return Promise.resolve({
            name: this._fromBaseNameToFullName(rootDirName, 'Chart.yaml'),
            data: YAML.dump(metadata)
        });
    }

    _getNormalizedTemplates(rootDirName){
        const templatesList = _.get(this._decodedObject, 'chart.templates', []) || [];
        return Promise.map(templatesList, (template) => {
            return {
                name: this._fromBaseNameToFullName(rootDirName, template.name),
                data: Buffer.from(template.data, 'base64').toString(),
            };
        });
    }

    _getNormalizedDependencies(rootDirName){
        const dependenciesList = _.get(this._decodedObject, 'chart.dependenciesList', []) || [];
        return Promise.map(dependenciesList, (dependency) => {
            const version = 1;
            const name = _.get(dependency, 'metadata.name');
            const data = {
                NAME: name,
                VERSION: version,
                MODIFIED_AT: this.modifiedAt,
                CREATED_AT: this.createdAt,
                STATUS: this.status,
            }
            const revision = new ReleaseRevision(data);
            revision._setDecodedObject({
                chart: dependency,
            })
            return revision.getChart(`Charts/${name}`);
        });
    }

    _getNormalizedValues(rootDirName){
        const values = _.get(this._decodedObject, 'chart.values', {});
        return Promise.resolve({
            name: this._fromBaseNameToFullName(rootDirName, 'values'),
            data: YAML.dump(values),
        });
    }

    _normalizeSecretKeys(obj) {
        return _.transform(obj, (result, value, key) => {
            result[_.lowerFirst(key)] = _.isObject(value) ? this._normalizeSecretKeys(value) : value;
        });
    }

    _getNormalizedFiles(rootDirName){
        const filesList = _.get(this._decodedObject, 'chart.files', []) || [];
        return Promise.map(filesList, (file) => {
            return {
                name: this._fromBaseNameToFullName(rootDirName, file.name),
                data: Buffer.from(file.data, 'base64').toString(),
            };
        });
    }


    getBasicData(){
        return {
            version: this._version,
            createdAt: this._createdAt,
            modifiedAt: this._modifiedAt,
            status: this._status,
            info: this._info,
            name: this._name
        }
    }

    init() {
        return this._getRevisionDecodedData()
            .then((decodedObject) => {
                this._setDecodedObject(decodedObject);
                this._createdAt = this._getUTCTime(_.get(decodedObject, 'info.first_deployed', 0));
                this._modifiedAt = this._getUTCTime(_.get(decodedObject, 'info.last_deployed', 0));
                this._info = _.get(decodedObject, 'info.description');
            });
    }

    getChart(baseName){
        return Promise.all([
            this._getNormalizedMetadata(baseName),
            this._getNormalizedTemplates(baseName),
            this._getNormalizedDependencies(baseName),
            this._getNormalizedValues(baseName),
            this._getNormalizedFiles(baseName),
        ])
        .then(_.flattenDeep)
        .then(_.compact);
    }

    getManifest(){
        return YAML.safeLoadAll(_.get(this.decodedObject, 'manifest', ''))
            .map(obj => Object.assign({
                data: YAML.dump(obj)
            }));
    }
    getValues(){
        return Object.assign({
            data: YAML.dump(_.get(this.decodedObject, 'config', ''))
        });
    }
    getHooks(){
        return _.get(this.decodedObject, 'hooksList', []).map(hook => Object.assign({
            name: _.get(hook, 'path', ''),
            data: YAML.dump(_.get(hook, 'manifest', ''))
        }));
    }

}

ReleaseRevision.commonProps = {
    name: 'name',
    status: 'status',
    version: 'version',
    modifiedAt: 'modifiedAt',
    createdAt: 'createdAt',
    statusses: {
        deployed: 'deployed'
    }
};

module.exports = ReleaseRevision;
